<?php
/**
 * Grouped product add to cart
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/add-to-cart/grouped.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce/Templates
 * @version     4.8.0
 */

defined( 'ABSPATH' ) || exit;

global $product, $post;

do_action( 'woocommerce_before_add_to_cart_form' ); ?>

<form class="cart grouped_form mb-4" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data'>
	<div class="woocommerce-grouped-product-list group_table mb-4">
		<?php
		$quantites_required      = false;
		$previous_post           = $post;
		$grouped_product_columns = apply_filters( 'woocommerce_grouped_product_columns', array(
			'label',
			'quantity',
			'price',
		), $product );

		foreach ( $grouped_products as $grouped_product_child ) {
			$post_object        = get_post( $grouped_product_child->get_id() );
			$quantites_required = $quantites_required || ( $grouped_product_child->is_purchasable() && ! $grouped_product_child->has_options() );
			$post               = $post_object; // WPCS: override ok.
			setup_postdata( $post );

			echo '<div id="product-' . esc_attr( $grouped_product_child->get_id() ) . '" class="woocommerce-grouped-product-list-item card card-body py-3 ' . esc_attr( implode( ' ', wc_get_product_class( '', $grouped_product_child ) ) ) . '">';

			// Output columns for each product.
			foreach ( $grouped_product_columns as $column_id ) {
				do_action( 'woocommerce_grouped_product_list_before_' . $column_id, $grouped_product_child );

				switch ( $column_id ) {
					case 'quantity':
						ob_start();

						if ( ! $grouped_product_child->is_purchasable() || $grouped_product_child->has_options() || ! $grouped_product_child->is_in_stock() ) {
							woocommerce_template_loop_add_to_cart();
						} elseif ( $grouped_product_child->is_sold_individually() ) {
							ob_start();
							?>
							<div class="custom-control custom-checkbox">
								<input type="checkbox"
								       id="wc-grouped-product-<?php echo absint( $grouped_product_child->get_id() ); ?>"
								       name="<?php echo esc_attr( 'quantity[' . $grouped_product_child->get_id() . ']' ); ?>"
								       value="1"
								       class="custom-control-input wc-grouped-product-add-to-cart-checkbox" />
								<label class="custom-control-label"
								       for="wc-grouped-product-<?php echo absint( $grouped_product_child->get_id() ); ?>">
									<?php echo esc_html_x( 'I want to buy one', 'front-end', 'cartzilla' ); ?>
									<?php echo esc_html( $grouped_product_child->get_name() ); ?>
								</label>
							</div>
							<?php
							echo '';
						} else {
							do_action( 'woocommerce_before_add_to_cart_quantity' );

							woocommerce_quantity_input( array(
								'input_name'  => 'quantity[' . $grouped_product_child->get_id() . ']',
								'input_value' => isset( $_POST['quantity'][ $grouped_product_child->get_id() ] ) ? wc_stock_amount( wc_clean( wp_unslash( $_POST['quantity'][ $grouped_product_child->get_id() ] ) ) ) : 0, // WPCS: CSRF ok, input var okay, sanitization ok.
								'min_value'   => apply_filters( 'woocommerce_quantity_input_min', 0, $grouped_product_child ),
								'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $grouped_product_child->get_max_purchase_quantity(), $grouped_product_child ),
								'classes'     => 'form-control',
							) );

							do_action( 'woocommerce_after_add_to_cart_quantity' );
						}

						$value = ob_get_clean();
						break;
					case 'label':
						$value  = '<label class="font-weight-medium" for="product-' . esc_attr( $grouped_product_child->get_id() ) . '">';
						$value .= $grouped_product_child->is_visible() ? '<a class="nav-link-style" href="' . esc_url( apply_filters( 'woocommerce_grouped_product_list_link', $grouped_product_child->get_permalink(), $grouped_product_child->get_id() ) ) . '">' . $grouped_product_child->get_name() . '<i class="czi-arrow-right font-size-xs ml-1"></i></a>' : $grouped_product_child->get_name();
						$value .= '</label>';
						break;
					case 'price':
						$value = '<div class="d-flex flex-wrap align-items-center pt-2">' . $grouped_product_child->get_price_html() . wc_get_stock_html( $grouped_product_child ) . '</div>';
						break;
					default:
						$value = '';
						break;
				}

				echo '<div class="woocommerce-grouped-product-list-item__' . esc_attr( $column_id ) . '">' . apply_filters( 'woocommerce_grouped_product_list_column_' . $column_id, $value, $grouped_product_child ) . '</div>'; // WPCS: XSS ok.

				do_action( 'woocommerce_grouped_product_list_after_' . $column_id, $grouped_product_child );
			}

			echo '</div>';
		}
		$post = $previous_post; // WPCS: override ok.
		setup_postdata( $post );
		?>
	</div>

	<input type="hidden" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" />

	<?php if ( $quantites_required ) : ?>

		<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

		<button type="submit" class="single_add_to_cart_button btn btn-primary btn-shadow btn-block">
			<i class='czi-cart font-size-lg mr-2'></i>
			<?php echo esc_html( $product->single_add_to_cart_text() ); ?>
		</button>

		<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>

	<?php endif; ?>
</form>

<?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>
